from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlockStats(_message.Message):
    __slots__ = ("fills",)
    class Fill(_message.Message):
        __slots__ = ("taker", "maker", "notional")
        TAKER_FIELD_NUMBER: _ClassVar[int]
        MAKER_FIELD_NUMBER: _ClassVar[int]
        NOTIONAL_FIELD_NUMBER: _ClassVar[int]
        taker: str
        maker: str
        notional: int
        def __init__(self, taker: _Optional[str] = ..., maker: _Optional[str] = ..., notional: _Optional[int] = ...) -> None: ...
    FILLS_FIELD_NUMBER: _ClassVar[int]
    fills: _containers.RepeatedCompositeFieldContainer[BlockStats.Fill]
    def __init__(self, fills: _Optional[_Iterable[_Union[BlockStats.Fill, _Mapping]]] = ...) -> None: ...

class StatsMetadata(_message.Message):
    __slots__ = ("trailing_epoch",)
    TRAILING_EPOCH_FIELD_NUMBER: _ClassVar[int]
    trailing_epoch: int
    def __init__(self, trailing_epoch: _Optional[int] = ...) -> None: ...

class EpochStats(_message.Message):
    __slots__ = ("epoch_end_time", "stats")
    class UserWithStats(_message.Message):
        __slots__ = ("user", "stats")
        USER_FIELD_NUMBER: _ClassVar[int]
        STATS_FIELD_NUMBER: _ClassVar[int]
        user: str
        stats: UserStats
        def __init__(self, user: _Optional[str] = ..., stats: _Optional[_Union[UserStats, _Mapping]] = ...) -> None: ...
    EPOCH_END_TIME_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    epoch_end_time: _timestamp_pb2.Timestamp
    stats: _containers.RepeatedCompositeFieldContainer[EpochStats.UserWithStats]
    def __init__(self, epoch_end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., stats: _Optional[_Iterable[_Union[EpochStats.UserWithStats, _Mapping]]] = ...) -> None: ...

class GlobalStats(_message.Message):
    __slots__ = ("notional_traded",)
    NOTIONAL_TRADED_FIELD_NUMBER: _ClassVar[int]
    notional_traded: int
    def __init__(self, notional_traded: _Optional[int] = ...) -> None: ...

class UserStats(_message.Message):
    __slots__ = ("taker_notional", "maker_notional")
    TAKER_NOTIONAL_FIELD_NUMBER: _ClassVar[int]
    MAKER_NOTIONAL_FIELD_NUMBER: _ClassVar[int]
    taker_notional: int
    maker_notional: int
    def __init__(self, taker_notional: _Optional[int] = ..., maker_notional: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.tendermint.types import types_pb2 as _types_pb2
from v4_proto.tendermint.types import evidence_pb2 as _evidence_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Block(_message.Message):
    __slots__ = ("header", "data", "evidence", "last_commit")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    LAST_COMMIT_FIELD_NUMBER: _ClassVar[int]
    header: _types_pb2.Header
    data: _types_pb2.Data
    evidence: _evidence_pb2.EvidenceList
    last_commit: _types_pb2.Commit
    def __init__(self, header: _Optional[_Union[_types_pb2.Header, _Mapping]] = ..., data: _Optional[_Union[_types_pb2.Data, _Mapping]] = ..., evidence: _Optional[_Union[_evidence_pb2.EvidenceList, _Mapping]] = ..., last_commit: _Optional[_Union[_types_pb2.Commit, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.dydxprotocol.bridge import query_pb2 as dydxprotocol_dot_bridge_dot_query__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in dydxprotocol/bridge/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EventParams = channel.unary_unary(
                '/dydxprotocol.bridge.Query/EventParams',
                request_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryEventParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryEventParamsResponse.FromString,
                _registered_method=True)
        self.ProposeParams = channel.unary_unary(
                '/dydxprotocol.bridge.Query/ProposeParams',
                request_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryProposeParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryProposeParamsResponse.FromString,
                _registered_method=True)
        self.SafetyParams = channel.unary_unary(
                '/dydxprotocol.bridge.Query/SafetyParams',
                request_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QuerySafetyParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QuerySafetyParamsResponse.FromString,
                _registered_method=True)
        self.AcknowledgedEventInfo = channel.unary_unary(
                '/dydxprotocol.bridge.Query/AcknowledgedEventInfo',
                request_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryAcknowledgedEventInfoRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryAcknowledgedEventInfoResponse.FromString,
                _registered_method=True)
        self.RecognizedEventInfo = channel.unary_unary(
                '/dydxprotocol.bridge.Query/RecognizedEventInfo',
                request_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryRecognizedEventInfoRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryRecognizedEventInfoResponse.FromString,
                _registered_method=True)
        self.DelayedCompleteBridgeMessages = channel.unary_unary(
                '/dydxprotocol.bridge.Query/DelayedCompleteBridgeMessages',
                request_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryDelayedCompleteBridgeMessagesRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryDelayedCompleteBridgeMessagesResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def EventParams(self, request, context):
        """Queries the EventParams.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposeParams(self, request, context):
        """Queries the ProposeParams.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SafetyParams(self, request, context):
        """Queries the SafetyParams.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcknowledgedEventInfo(self, request, context):
        """Queries the AcknowledgedEventInfo.
        An "acknowledged" event is one that is in-consensus and has been stored
        in-state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecognizedEventInfo(self, request, context):
        """Queries the RecognizedEventInfo.
        A "recognized" event is one that is finalized on the Ethereum blockchain
        and has been identified by the queried node. It is not yet in-consensus.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DelayedCompleteBridgeMessages(self, request, context):
        """Queries all `MsgCompleteBridge` messages that are delayed (not yet
        executed) and corresponding block heights at which they will execute.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'EventParams': grpc.unary_unary_rpc_method_handler(
                    servicer.EventParams,
                    request_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryEventParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryEventParamsResponse.SerializeToString,
            ),
            'ProposeParams': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposeParams,
                    request_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryProposeParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryProposeParamsResponse.SerializeToString,
            ),
            'SafetyParams': grpc.unary_unary_rpc_method_handler(
                    servicer.SafetyParams,
                    request_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QuerySafetyParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QuerySafetyParamsResponse.SerializeToString,
            ),
            'AcknowledgedEventInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.AcknowledgedEventInfo,
                    request_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryAcknowledgedEventInfoRequest.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryAcknowledgedEventInfoResponse.SerializeToString,
            ),
            'RecognizedEventInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.RecognizedEventInfo,
                    request_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryRecognizedEventInfoRequest.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryRecognizedEventInfoResponse.SerializeToString,
            ),
            'DelayedCompleteBridgeMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.DelayedCompleteBridgeMessages,
                    request_deserializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryDelayedCompleteBridgeMessagesRequest.FromString,
                    response_serializer=dydxprotocol_dot_bridge_dot_query__pb2.QueryDelayedCompleteBridgeMessagesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.bridge.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('dydxprotocol.bridge.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def EventParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.bridge.Query/EventParams',
            dydxprotocol_dot_bridge_dot_query__pb2.QueryEventParamsRequest.SerializeToString,
            dydxprotocol_dot_bridge_dot_query__pb2.QueryEventParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ProposeParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.bridge.Query/ProposeParams',
            dydxprotocol_dot_bridge_dot_query__pb2.QueryProposeParamsRequest.SerializeToString,
            dydxprotocol_dot_bridge_dot_query__pb2.QueryProposeParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SafetyParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.bridge.Query/SafetyParams',
            dydxprotocol_dot_bridge_dot_query__pb2.QuerySafetyParamsRequest.SerializeToString,
            dydxprotocol_dot_bridge_dot_query__pb2.QuerySafetyParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcknowledgedEventInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.bridge.Query/AcknowledgedEventInfo',
            dydxprotocol_dot_bridge_dot_query__pb2.QueryAcknowledgedEventInfoRequest.SerializeToString,
            dydxprotocol_dot_bridge_dot_query__pb2.QueryAcknowledgedEventInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RecognizedEventInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.bridge.Query/RecognizedEventInfo',
            dydxprotocol_dot_bridge_dot_query__pb2.QueryRecognizedEventInfoRequest.SerializeToString,
            dydxprotocol_dot_bridge_dot_query__pb2.QueryRecognizedEventInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DelayedCompleteBridgeMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.bridge.Query/DelayedCompleteBridgeMessages',
            dydxprotocol_dot_bridge_dot_query__pb2.QueryDelayedCompleteBridgeMessagesRequest.SerializeToString,
            dydxprotocol_dot_bridge_dot_query__pb2.QueryDelayedCompleteBridgeMessagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.ratelimit import limit_params_pb2 as _limit_params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DenomCapacity(_message.Message):
    __slots__ = ("denom", "capacity_list")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    CAPACITY_LIST_FIELD_NUMBER: _ClassVar[int]
    denom: str
    capacity_list: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, denom: _Optional[str] = ..., capacity_list: _Optional[_Iterable[bytes]] = ...) -> None: ...

class LimiterCapacity(_message.Message):
    __slots__ = ("limiter", "capacity")
    LIMITER_FIELD_NUMBER: _ClassVar[int]
    CAPACITY_FIELD_NUMBER: _ClassVar[int]
    limiter: _limit_params_pb2.Limiter
    capacity: bytes
    def __init__(self, limiter: _Optional[_Union[_limit_params_pb2.Limiter, _Mapping]] = ..., capacity: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/circuit/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.cosmos.circuit.v1 import types_pb2 as cosmos_dot_circuit_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63osmos/circuit/v1/tx.proto\x12\x11\x63osmos.circuit.v1\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1d\x63osmos/circuit/v1/types.proto\"\x81\x01\n\x1aMsgAuthorizeCircuitBreaker\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x33\n\x0bpermissions\x18\x03 \x01(\x0b\x32\x1e.cosmos.circuit.v1.Permissions:\x0c\x82\xe7\xb0*\x07granter\"5\n\"MsgAuthorizeCircuitBreakerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"Q\n\x15MsgTripCircuitBreaker\x12\x11\n\tauthority\x18\x01 \x01(\t\x12\x15\n\rmsg_type_urls\x18\x02 \x03(\t:\x0e\x82\xe7\xb0*\tauthority\"0\n\x1dMsgTripCircuitBreakerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"R\n\x16MsgResetCircuitBreaker\x12\x11\n\tauthority\x18\x01 \x01(\t\x12\x15\n\rmsg_type_urls\x18\x03 \x03(\t:\x0e\x82\xe7\xb0*\tauthority\"1\n\x1eMsgResetCircuitBreakerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xf4\x02\n\x03Msg\x12\x7f\n\x17\x41uthorizeCircuitBreaker\x12-.cosmos.circuit.v1.MsgAuthorizeCircuitBreaker\x1a\x35.cosmos.circuit.v1.MsgAuthorizeCircuitBreakerResponse\x12p\n\x12TripCircuitBreaker\x12(.cosmos.circuit.v1.MsgTripCircuitBreaker\x1a\x30.cosmos.circuit.v1.MsgTripCircuitBreakerResponse\x12s\n\x13ResetCircuitBreaker\x12).cosmos.circuit.v1.MsgResetCircuitBreaker\x1a\x31.cosmos.circuit.v1.MsgResetCircuitBreakerResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x1eZ\x1c\x63osmossdk.io/x/circuit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.circuit.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\034cosmossdk.io/x/circuit/types'
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._loaded_options = None
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_options = b'\202\347\260*\007granter'
  _globals['_MSGTRIPCIRCUITBREAKER']._loaded_options = None
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGRESETCIRCUITBREAKER']._loaded_options = None
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_start=106
  _globals['_MSGAUTHORIZECIRCUITBREAKER']._serialized_end=235
  _globals['_MSGAUTHORIZECIRCUITBREAKERRESPONSE']._serialized_start=237
  _globals['_MSGAUTHORIZECIRCUITBREAKERRESPONSE']._serialized_end=290
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_start=292
  _globals['_MSGTRIPCIRCUITBREAKER']._serialized_end=373
  _globals['_MSGTRIPCIRCUITBREAKERRESPONSE']._serialized_start=375
  _globals['_MSGTRIPCIRCUITBREAKERRESPONSE']._serialized_end=423
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_start=425
  _globals['_MSGRESETCIRCUITBREAKER']._serialized_end=507
  _globals['_MSGRESETCIRCUITBREAKERRESPONSE']._serialized_start=509
  _globals['_MSGRESETCIRCUITBREAKERRESPONSE']._serialized_end=558
  _globals['_MSG']._serialized_start=561
  _globals['_MSG']._serialized_end=933
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.gov.v1 import gov_pb2 as cosmos_dot_gov_dot_v1_dot_gov__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63osmos/gov/v1/query.proto\x12\rcosmos.gov.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17\x63osmos/gov/v1/gov.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\x1a\n\x18QueryConstitutionRequest\"1\n\x19QueryConstitutionResponse\x12\x14\n\x0c\x63onstitution\x18\x01 \x01(\t\"+\n\x14QueryProposalRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"B\n\x15QueryProposalResponse\x12)\n\x08proposal\x18\x01 \x01(\x0b\x32\x17.cosmos.gov.v1.Proposal\"\xe1\x01\n\x15QueryProposalsRequest\x12\x36\n\x0fproposal_status\x18\x01 \x01(\x0e\x32\x1d.cosmos.gov.v1.ProposalStatus\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12+\n\tdepositor\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x81\x01\n\x16QueryProposalsResponse\x12*\n\tproposals\x18\x01 \x03(\x0b\x32\x17.cosmos.gov.v1.Proposal\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"P\n\x10QueryVoteRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"6\n\x11QueryVoteResponse\x12!\n\x04vote\x18\x01 \x01(\x0b\x32\x13.cosmos.gov.v1.Vote\"d\n\x11QueryVotesRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"u\n\x12QueryVotesResponse\x12\"\n\x05votes\x18\x01 \x03(\x0b\x32\x13.cosmos.gov.v1.Vote\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\")\n\x12QueryParamsRequest\x12\x13\n\x0bparams_type\x18\x01 \x01(\t\"\xe4\x01\n\x13QueryParamsResponse\x12\x36\n\rvoting_params\x18\x01 \x01(\x0b\x32\x1b.cosmos.gov.v1.VotingParamsB\x02\x18\x01\x12\x38\n\x0e\x64\x65posit_params\x18\x02 \x01(\x0b\x32\x1c.cosmos.gov.v1.DepositParamsB\x02\x18\x01\x12\x34\n\x0ctally_params\x18\x03 \x01(\x0b\x32\x1a.cosmos.gov.v1.TallyParamsB\x02\x18\x01\x12%\n\x06params\x18\x04 \x01(\x0b\x32\x15.cosmos.gov.v1.Params\"W\n\x13QueryDepositRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"?\n\x14QueryDepositResponse\x12\'\n\x07\x64\x65posit\x18\x01 \x01(\x0b\x32\x16.cosmos.gov.v1.Deposit\"g\n\x14QueryDepositsRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"~\n\x15QueryDepositsResponse\x12(\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32\x16.cosmos.gov.v1.Deposit\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\".\n\x17QueryTallyResultRequest\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"E\n\x18QueryTallyResultResponse\x12)\n\x05tally\x18\x01 \x01(\x0b\x32\x1a.cosmos.gov.v1.TallyResult2\xe3\t\n\x05Query\x12\x86\x01\n\x0c\x43onstitution\x12\'.cosmos.gov.v1.QueryConstitutionRequest\x1a(.cosmos.gov.v1.QueryConstitutionResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/gov/v1/constitution\x12\x85\x01\n\x08Proposal\x12#.cosmos.gov.v1.QueryProposalRequest\x1a$.cosmos.gov.v1.QueryProposalResponse\".\x82\xd3\xe4\x93\x02(\x12&/cosmos/gov/v1/proposals/{proposal_id}\x12z\n\tProposals\x12$.cosmos.gov.v1.QueryProposalsRequest\x1a%.cosmos.gov.v1.QueryProposalsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/cosmos/gov/v1/proposals\x12\x87\x01\n\x04Vote\x12\x1f.cosmos.gov.v1.QueryVoteRequest\x1a .cosmos.gov.v1.QueryVoteResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/gov/v1/proposals/{proposal_id}/votes/{voter}\x12\x82\x01\n\x05Votes\x12 .cosmos.gov.v1.QueryVotesRequest\x1a!.cosmos.gov.v1.QueryVotesResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/gov/v1/proposals/{proposal_id}/votes\x12|\n\x06Params\x12!.cosmos.gov.v1.QueryParamsRequest\x1a\".cosmos.gov.v1.QueryParamsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/cosmos/gov/v1/params/{params_type}\x12\x97\x01\n\x07\x44\x65posit\x12\".cosmos.gov.v1.QueryDepositRequest\x1a#.cosmos.gov.v1.QueryDepositResponse\"C\x82\xd3\xe4\x93\x02=\x12;/cosmos/gov/v1/proposals/{proposal_id}/deposits/{depositor}\x12\x8e\x01\n\x08\x44\x65posits\x12#.cosmos.gov.v1.QueryDepositsRequest\x1a$.cosmos.gov.v1.QueryDepositsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//cosmos/gov/v1/proposals/{proposal_id}/deposits\x12\x94\x01\n\x0bTallyResult\x12&.cosmos.gov.v1.QueryTallyResultRequest\x1a\'.cosmos.gov.v1.QueryTallyResultResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/gov/v1/proposals/{proposal_id}/tallyB-Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/gov/types/v1'
  _globals['_QUERYPROPOSALSREQUEST'].fields_by_name['voter']._loaded_options = None
  _globals['_QUERYPROPOSALSREQUEST'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYPROPOSALSREQUEST'].fields_by_name['depositor']._loaded_options = None
  _globals['_QUERYPROPOSALSREQUEST'].fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYVOTEREQUEST'].fields_by_name['voter']._loaded_options = None
  _globals['_QUERYVOTEREQUEST'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['voting_params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['voting_params']._serialized_options = b'\030\001'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['deposit_params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['deposit_params']._serialized_options = b'\030\001'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['tally_params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['tally_params']._serialized_options = b'\030\001'
  _globals['_QUERYDEPOSITREQUEST'].fields_by_name['depositor']._loaded_options = None
  _globals['_QUERYDEPOSITREQUEST'].fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['Constitution']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Constitution']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/gov/v1/constitution'
  _globals['_QUERY'].methods_by_name['Proposal']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Proposal']._serialized_options = b'\202\323\344\223\002(\022&/cosmos/gov/v1/proposals/{proposal_id}'
  _globals['_QUERY'].methods_by_name['Proposals']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Proposals']._serialized_options = b'\202\323\344\223\002\032\022\030/cosmos/gov/v1/proposals'
  _globals['_QUERY'].methods_by_name['Vote']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Vote']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/gov/v1/proposals/{proposal_id}/votes/{voter}'
  _globals['_QUERY'].methods_by_name['Votes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Votes']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/gov/v1/proposals/{proposal_id}/votes'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002%\022#/cosmos/gov/v1/params/{params_type}'
  _globals['_QUERY'].methods_by_name['Deposit']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Deposit']._serialized_options = b'\202\323\344\223\002=\022;/cosmos/gov/v1/proposals/{proposal_id}/deposits/{depositor}'
  _globals['_QUERY'].methods_by_name['Deposits']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Deposits']._serialized_options = b'\202\323\344\223\0021\022//cosmos/gov/v1/proposals/{proposal_id}/deposits'
  _globals['_QUERY'].methods_by_name['TallyResult']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TallyResult']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/gov/v1/proposals/{proposal_id}/tally'
  _globals['_QUERYCONSTITUTIONREQUEST']._serialized_start=170
  _globals['_QUERYCONSTITUTIONREQUEST']._serialized_end=196
  _globals['_QUERYCONSTITUTIONRESPONSE']._serialized_start=198
  _globals['_QUERYCONSTITUTIONRESPONSE']._serialized_end=247
  _globals['_QUERYPROPOSALREQUEST']._serialized_start=249
  _globals['_QUERYPROPOSALREQUEST']._serialized_end=292
  _globals['_QUERYPROPOSALRESPONSE']._serialized_start=294
  _globals['_QUERYPROPOSALRESPONSE']._serialized_end=360
  _globals['_QUERYPROPOSALSREQUEST']._serialized_start=363
  _globals['_QUERYPROPOSALSREQUEST']._serialized_end=588
  _globals['_QUERYPROPOSALSRESPONSE']._serialized_start=591
  _globals['_QUERYPROPOSALSRESPONSE']._serialized_end=720
  _globals['_QUERYVOTEREQUEST']._serialized_start=722
  _globals['_QUERYVOTEREQUEST']._serialized_end=802
  _globals['_QUERYVOTERESPONSE']._serialized_start=804
  _globals['_QUERYVOTERESPONSE']._serialized_end=858
  _globals['_QUERYVOTESREQUEST']._serialized_start=860
  _globals['_QUERYVOTESREQUEST']._serialized_end=960
  _globals['_QUERYVOTESRESPONSE']._serialized_start=962
  _globals['_QUERYVOTESRESPONSE']._serialized_end=1079
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1081
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1122
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1125
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1353
  _globals['_QUERYDEPOSITREQUEST']._serialized_start=1355
  _globals['_QUERYDEPOSITREQUEST']._serialized_end=1442
  _globals['_QUERYDEPOSITRESPONSE']._serialized_start=1444
  _globals['_QUERYDEPOSITRESPONSE']._serialized_end=1507
  _globals['_QUERYDEPOSITSREQUEST']._serialized_start=1509
  _globals['_QUERYDEPOSITSREQUEST']._serialized_end=1612
  _globals['_QUERYDEPOSITSRESPONSE']._serialized_start=1614
  _globals['_QUERYDEPOSITSRESPONSE']._serialized_end=1740
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_start=1742
  _globals['_QUERYTALLYRESULTREQUEST']._serialized_end=1788
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_start=1790
  _globals['_QUERYTALLYRESULTRESPONSE']._serialized_end=1859
  _globals['_QUERY']._serialized_start=1862
  _globals['_QUERY']._serialized_end=3113
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/indexer/socks/messages.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.indexer.protocol.v1 import subaccount_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)dydxprotocol/indexer/socks/messages.proto\x12\x1a\x64ydxprotocol.indexer.socks\x1a\x31\x64ydxprotocol/indexer/protocol/v1/subaccount.proto\"K\n\x10OrderbookMessage\x12\x10\n\x08\x63ontents\x18\x01 \x01(\t\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xca\x01\n\x11SubaccountMessage\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\t\x12\x19\n\x11transaction_index\x18\x02 \x01(\x05\x12\x13\n\x0b\x65vent_index\x18\x03 \x01(\r\x12\x10\n\x08\x63ontents\x18\x04 \x01(\t\x12L\n\rsubaccount_id\x18\x05 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountId\x12\x0f\n\x07version\x18\x06 \x01(\t\"]\n\x0cTradeMessage\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\t\x12\x10\n\x08\x63ontents\x18\x04 \x01(\t\x12\x14\n\x0c\x63lob_pair_id\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\"2\n\rMarketMessage\x12\x10\n\x08\x63ontents\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x97\x02\n\rCandleMessage\x12\x10\n\x08\x63ontents\x18\x01 \x01(\t\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\t\x12H\n\nresolution\x18\x03 \x01(\x0e\x32\x34.dydxprotocol.indexer.socks.CandleMessage.Resolution\x12\x0f\n\x07version\x18\x04 \x01(\t\"\x82\x01\n\nResolution\x12\x0e\n\nONE_MINUTE\x10\x00\x12\x10\n\x0c\x46IVE_MINUTES\x10\x01\x12\x13\n\x0f\x46IFTEEN_MINUTES\x10\x02\x12\x12\n\x0eTHIRTY_MINUTES\x10\x03\x12\x0c\n\x08ONE_HOUR\x10\x04\x12\x0e\n\nFOUR_HOURS\x10\x05\x12\x0b\n\x07ONE_DAY\x10\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.socks.messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ORDERBOOKMESSAGE']._serialized_start=124
  _globals['_ORDERBOOKMESSAGE']._serialized_end=199
  _globals['_SUBACCOUNTMESSAGE']._serialized_start=202
  _globals['_SUBACCOUNTMESSAGE']._serialized_end=404
  _globals['_TRADEMESSAGE']._serialized_start=406
  _globals['_TRADEMESSAGE']._serialized_end=499
  _globals['_MARKETMESSAGE']._serialized_start=501
  _globals['_MARKETMESSAGE']._serialized_end=551
  _globals['_CANDLEMESSAGE']._serialized_start=554
  _globals['_CANDLEMESSAGE']._serialized_end=833
  _globals['_CANDLEMESSAGE_RESOLUTION']._serialized_start=703
  _globals['_CANDLEMESSAGE_RESOLUTION']._serialized_end=833
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgGrantAllowance(_message.Message):
    __slots__ = ("granter", "grantee", "allowance")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    ALLOWANCE_FIELD_NUMBER: _ClassVar[int]
    granter: str
    grantee: str
    allowance: _any_pb2.Any
    def __init__(self, granter: _Optional[str] = ..., grantee: _Optional[str] = ..., allowance: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class MsgGrantAllowanceResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRevokeAllowance(_message.Message):
    __slots__ = ("granter", "grantee")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    granter: str
    grantee: str
    def __init__(self, granter: _Optional[str] = ..., grantee: _Optional[str] = ...) -> None: ...

class MsgRevokeAllowanceResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgPruneAllowances(_message.Message):
    __slots__ = ("pruner",)
    PRUNER_FIELD_NUMBER: _ClassVar[int]
    pruner: str
    def __init__(self, pruner: _Optional[str] = ...) -> None: ...

class MsgPruneAllowancesResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.epochs import epoch_info_pb2 as _epoch_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("epoch_info_list",)
    EPOCH_INFO_LIST_FIELD_NUMBER: _ClassVar[int]
    epoch_info_list: _containers.RepeatedCompositeFieldContainer[_epoch_info_pb2.EpochInfo]
    def __init__(self, epoch_info_list: _Optional[_Iterable[_Union[_epoch_info_pb2.EpochInfo, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/delaymsg/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.delaymsg import delayed_message_pb2 as dydxprotocol_dot_delaymsg_dot_delayed__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/delaymsg/query.proto\x12\x15\x64ydxprotocol.delaymsg\x1a\x1cgoogle/api/annotations.proto\x1a+dydxprotocol/delaymsg/delayed_message.proto\"\"\n QueryNextDelayedMessageIdRequest\"D\n!QueryNextDelayedMessageIdResponse\x12\x1f\n\x17next_delayed_message_id\x18\x01 \x01(\r\"!\n\x13QueryMessageRequest\x12\n\n\x02id\x18\x01 \x01(\r\"N\n\x14QueryMessageResponse\x12\x36\n\x07message\x18\x01 \x01(\x0b\x32%.dydxprotocol.delaymsg.DelayedMessage\"3\n\x1bQueryBlockMessageIdsRequest\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\r\"3\n\x1cQueryBlockMessageIdsResponse\x12\x13\n\x0bmessage_ids\x18\x01 \x03(\r2\x94\x04\n\x05Query\x12\xb4\x01\n\x14NextDelayedMessageId\x12\x37.dydxprotocol.delaymsg.QueryNextDelayedMessageIdRequest\x1a\x38.dydxprotocol.delaymsg.QueryNextDelayedMessageIdResponse\")\x82\xd3\xe4\x93\x02#\x12!/dydxprotocol/v4/delaymsg/next_id\x12\x92\x01\n\x07Message\x12*.dydxprotocol.delaymsg.QueryMessageRequest\x1a+.dydxprotocol.delaymsg.QueryMessageResponse\".\x82\xd3\xe4\x93\x02(\x12&/dydxprotocol/v4/delaymsg/message/{id}\x12\xbe\x01\n\x0f\x42lockMessageIds\x12\x32.dydxprotocol.delaymsg.QueryBlockMessageIdsRequest\x1a\x33.dydxprotocol.delaymsg.QueryBlockMessageIdsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/dydxprotocol/v4/delaymsg/block/message_ids/{block_height}B<Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.delaymsg.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/types'
  _globals['_QUERY'].methods_by_name['NextDelayedMessageId']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NextDelayedMessageId']._serialized_options = b'\202\323\344\223\002#\022!/dydxprotocol/v4/delaymsg/next_id'
  _globals['_QUERY'].methods_by_name['Message']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Message']._serialized_options = b'\202\323\344\223\002(\022&/dydxprotocol/v4/delaymsg/message/{id}'
  _globals['_QUERY'].methods_by_name['BlockMessageIds']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BlockMessageIds']._serialized_options = b'\202\323\344\223\002<\022:/dydxprotocol/v4/delaymsg/block/message_ids/{block_height}'
  _globals['_QUERYNEXTDELAYEDMESSAGEIDREQUEST']._serialized_start=135
  _globals['_QUERYNEXTDELAYEDMESSAGEIDREQUEST']._serialized_end=169
  _globals['_QUERYNEXTDELAYEDMESSAGEIDRESPONSE']._serialized_start=171
  _globals['_QUERYNEXTDELAYEDMESSAGEIDRESPONSE']._serialized_end=239
  _globals['_QUERYMESSAGEREQUEST']._serialized_start=241
  _globals['_QUERYMESSAGEREQUEST']._serialized_end=274
  _globals['_QUERYMESSAGERESPONSE']._serialized_start=276
  _globals['_QUERYMESSAGERESPONSE']._serialized_end=354
  _globals['_QUERYBLOCKMESSAGEIDSREQUEST']._serialized_start=356
  _globals['_QUERYBLOCKMESSAGEIDSREQUEST']._serialized_end=407
  _globals['_QUERYBLOCKMESSAGEIDSRESPONSE']._serialized_start=409
  _globals['_QUERYBLOCKMESSAGEIDSRESPONSE']._serialized_end=460
  _globals['_QUERY']._serialized_start=463
  _globals['_QUERY']._serialized_end=995
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/version/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/version/types.proto\x12\x12tendermint.version\x1a\x14gogoproto/gogo.proto\")\n\x03\x41pp\x12\x10\n\x08protocol\x18\x01 \x01(\x04\x12\x10\n\x08software\x18\x02 \x01(\t\"-\n\tConsensus\x12\r\n\x05\x62lock\x18\x01 \x01(\x04\x12\x0b\n\x03\x61pp\x18\x02 \x01(\x04:\x04\xe8\xa0\x1f\x01\x42\x37Z5github.com/cometbft/cometbft/proto/tendermint/versionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.version.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/cometbft/cometbft/proto/tendermint/version'
  _globals['_CONSENSUS']._loaded_options = None
  _globals['_CONSENSUS']._serialized_options = b'\350\240\037\001'
  _globals['_APP']._serialized_start=76
  _globals['_APP']._serialized_end=117
  _globals['_CONSENSUS']._serialized_start=119
  _globals['_CONSENSUS']._serialized_end=164
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/feetiers/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.feetiers import params_pb2 as dydxprotocol_dot_feetiers_dot_params__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/feetiers/tx.proto\x12\x15\x64ydxprotocol.feetiers\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\"dydxprotocol/feetiers/params.proto\x1a\x14gogoproto/gogo.proto\"\x9b\x01\n\x1bMsgUpdatePerpetualFeeParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12?\n\x06params\x18\x02 \x01(\x0b\x32).dydxprotocol.feetiers.PerpetualFeeParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"%\n#MsgUpdatePerpetualFeeParamsResponse2\x92\x01\n\x03Msg\x12\x8a\x01\n\x18UpdatePerpetualFeeParams\x12\x32.dydxprotocol.feetiers.MsgUpdatePerpetualFeeParams\x1a:.dydxprotocol.feetiers.MsgUpdatePerpetualFeeParamsResponseB<Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.feetiers.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/types'
  _globals['_MSGUPDATEPERPETUALFEEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALFEEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPERPETUALFEEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALFEEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPERPETUALFEEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPERPETUALFEEPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEPERPETUALFEEPARAMS']._serialized_start=168
  _globals['_MSGUPDATEPERPETUALFEEPARAMS']._serialized_end=323
  _globals['_MSGUPDATEPERPETUALFEEPARAMSRESPONSE']._serialized_start=325
  _globals['_MSGUPDATEPERPETUALFEEPARAMSRESPONSE']._serialized_end=362
  _globals['_MSG']._serialized_start=365
  _globals['_MSG']._serialized_end=511
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.ratelimit import limit_params_pb2 as _limit_params_pb2
from v4_proto.dydxprotocol.ratelimit import capacity_pb2 as _capacity_pb2
from v4_proto.dydxprotocol.ratelimit import pending_send_packet_pb2 as _pending_send_packet_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListLimitParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListLimitParamsResponse(_message.Message):
    __slots__ = ("limit_params_list",)
    LIMIT_PARAMS_LIST_FIELD_NUMBER: _ClassVar[int]
    limit_params_list: _containers.RepeatedCompositeFieldContainer[_limit_params_pb2.LimitParams]
    def __init__(self, limit_params_list: _Optional[_Iterable[_Union[_limit_params_pb2.LimitParams, _Mapping]]] = ...) -> None: ...

class QueryCapacityByDenomRequest(_message.Message):
    __slots__ = ("denom",)
    DENOM_FIELD_NUMBER: _ClassVar[int]
    denom: str
    def __init__(self, denom: _Optional[str] = ...) -> None: ...

class QueryCapacityByDenomResponse(_message.Message):
    __slots__ = ("limiter_capacity_list",)
    LIMITER_CAPACITY_LIST_FIELD_NUMBER: _ClassVar[int]
    limiter_capacity_list: _containers.RepeatedCompositeFieldContainer[_capacity_pb2.LimiterCapacity]
    def __init__(self, limiter_capacity_list: _Optional[_Iterable[_Union[_capacity_pb2.LimiterCapacity, _Mapping]]] = ...) -> None: ...

class QueryAllPendingSendPacketsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryAllPendingSendPacketsResponse(_message.Message):
    __slots__ = ("pending_send_packets",)
    PENDING_SEND_PACKETS_FIELD_NUMBER: _ClassVar[int]
    pending_send_packets: _containers.RepeatedCompositeFieldContainer[_pending_send_packet_pb2.PendingSendPacket]
    def __init__(self, pending_send_packets: _Optional[_Iterable[_Union[_pending_send_packet_pb2.PendingSendPacket, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/feetiers/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dydxprotocol/feetiers/params.proto\x12\x15\x64ydxprotocol.feetiers\"L\n\x12PerpetualFeeParams\x12\x36\n\x05tiers\x18\x01 \x03(\x0b\x32\'.dydxprotocol.feetiers.PerpetualFeeTier\"\xcb\x01\n\x10PerpetualFeeTier\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x1b\x61\x62solute_volume_requirement\x18\x02 \x01(\x04\x12*\n\"total_volume_share_requirement_ppm\x18\x03 \x01(\r\x12*\n\"maker_volume_share_requirement_ppm\x18\x04 \x01(\r\x12\x15\n\rmaker_fee_ppm\x18\x05 \x01(\x11\x12\x15\n\rtaker_fee_ppm\x18\x06 \x01(\x11\x42<Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.feetiers.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/feetiers/types'
  _globals['_PERPETUALFEEPARAMS']._serialized_start=61
  _globals['_PERPETUALFEEPARAMS']._serialized_end=137
  _globals['_PERPETUALFEETIER']._serialized_start=140
  _globals['_PERPETUALFEETIER']._serialized_end=343
# @@protoc_insertion_point(module_scope)



from v4_proto.dydxprotocol.indexer.protocol.v1 import subaccount_pb2 as _subaccount_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ClobPairStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CLOB_PAIR_STATUS_UNSPECIFIED: _ClassVar[ClobPairStatus]
    CLOB_PAIR_STATUS_ACTIVE: _ClassVar[ClobPairStatus]
    CLOB_PAIR_STATUS_PAUSED: _ClassVar[ClobPairStatus]
    CLOB_PAIR_STATUS_CANCEL_ONLY: _ClassVar[ClobPairStatus]
    CLOB_PAIR_STATUS_POST_ONLY: _ClassVar[ClobPairStatus]
    CLOB_PAIR_STATUS_INITIALIZING: _ClassVar[ClobPairStatus]
    CLOB_PAIR_STATUS_FINAL_SETTLEMENT: _ClassVar[ClobPairStatus]
CLOB_PAIR_STATUS_UNSPECIFIED: ClobPairStatus
CLOB_PAIR_STATUS_ACTIVE: ClobPairStatus
CLOB_PAIR_STATUS_PAUSED: ClobPairStatus
CLOB_PAIR_STATUS_CANCEL_ONLY: ClobPairStatus
CLOB_PAIR_STATUS_POST_ONLY: ClobPairStatus
CLOB_PAIR_STATUS_INITIALIZING: ClobPairStatus
CLOB_PAIR_STATUS_FINAL_SETTLEMENT: ClobPairStatus

class IndexerOrderId(_message.Message):
    __slots__ = ("subaccount_id", "client_id", "order_flags", "clob_pair_id")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_FLAGS_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.IndexerSubaccountId
    client_id: int
    order_flags: int
    clob_pair_id: int
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.IndexerSubaccountId, _Mapping]] = ..., client_id: _Optional[int] = ..., order_flags: _Optional[int] = ..., clob_pair_id: _Optional[int] = ...) -> None: ...

class IndexerOrder(_message.Message):
    __slots__ = ("order_id", "side", "quantums", "subticks", "good_til_block", "good_til_block_time", "time_in_force", "reduce_only", "client_metadata", "condition_type", "conditional_order_trigger_subticks")
    class Side(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SIDE_UNSPECIFIED: _ClassVar[IndexerOrder.Side]
        SIDE_BUY: _ClassVar[IndexerOrder.Side]
        SIDE_SELL: _ClassVar[IndexerOrder.Side]
    SIDE_UNSPECIFIED: IndexerOrder.Side
    SIDE_BUY: IndexerOrder.Side
    SIDE_SELL: IndexerOrder.Side
    class TimeInForce(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TIME_IN_FORCE_UNSPECIFIED: _ClassVar[IndexerOrder.TimeInForce]
        TIME_IN_FORCE_IOC: _ClassVar[IndexerOrder.TimeInForce]
        TIME_IN_FORCE_POST_ONLY: _ClassVar[IndexerOrder.TimeInForce]
        TIME_IN_FORCE_FILL_OR_KILL: _ClassVar[IndexerOrder.TimeInForce]
    TIME_IN_FORCE_UNSPECIFIED: IndexerOrder.TimeInForce
    TIME_IN_FORCE_IOC: IndexerOrder.TimeInForce
    TIME_IN_FORCE_POST_ONLY: IndexerOrder.TimeInForce
    TIME_IN_FORCE_FILL_OR_KILL: IndexerOrder.TimeInForce
    class ConditionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        CONDITION_TYPE_UNSPECIFIED: _ClassVar[IndexerOrder.ConditionType]
        CONDITION_TYPE_STOP_LOSS: _ClassVar[IndexerOrder.ConditionType]
        CONDITION_TYPE_TAKE_PROFIT: _ClassVar[IndexerOrder.ConditionType]
    CONDITION_TYPE_UNSPECIFIED: IndexerOrder.ConditionType
    CONDITION_TYPE_STOP_LOSS: IndexerOrder.ConditionType
    CONDITION_TYPE_TAKE_PROFIT: IndexerOrder.ConditionType
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    SIDE_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_FIELD_NUMBER: _ClassVar[int]
    GOOD_TIL_BLOCK_FIELD_NUMBER: _ClassVar[int]
    GOOD_TIL_BLOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    TIME_IN_FORCE_FIELD_NUMBER: _ClassVar[int]
    REDUCE_ONLY_FIELD_NUMBER: _ClassVar[int]
    CLIENT_METADATA_FIELD_NUMBER: _ClassVar[int]
    CONDITION_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONDITIONAL_ORDER_TRIGGER_SUBTICKS_FIELD_NUMBER: _ClassVar[int]
    order_id: IndexerOrderId
    side: IndexerOrder.Side
    quantums: int
    subticks: int
    good_til_block: int
    good_til_block_time: int
    time_in_force: IndexerOrder.TimeInForce
    reduce_only: bool
    client_metadata: int
    condition_type: IndexerOrder.ConditionType
    conditional_order_trigger_subticks: int
    def __init__(self, order_id: _Optional[_Union[IndexerOrderId, _Mapping]] = ..., side: _Optional[_Union[IndexerOrder.Side, str]] = ..., quantums: _Optional[int] = ..., subticks: _Optional[int] = ..., good_til_block: _Optional[int] = ..., good_til_block_time: _Optional[int] = ..., time_in_force: _Optional[_Union[IndexerOrder.TimeInForce, str]] = ..., reduce_only: bool = ..., client_metadata: _Optional[int] = ..., condition_type: _Optional[_Union[IndexerOrder.ConditionType, str]] = ..., conditional_order_trigger_subticks: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
GOPROTO_ENUM_PREFIX_FIELD_NUMBER: _ClassVar[int]
goproto_enum_prefix: _descriptor.FieldDescriptor
GOPROTO_ENUM_STRINGER_FIELD_NUMBER: _ClassVar[int]
goproto_enum_stringer: _descriptor.FieldDescriptor
ENUM_STRINGER_FIELD_NUMBER: _ClassVar[int]
enum_stringer: _descriptor.FieldDescriptor
ENUM_CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
enum_customname: _descriptor.FieldDescriptor
ENUMDECL_FIELD_NUMBER: _ClassVar[int]
enumdecl: _descriptor.FieldDescriptor
ENUMVALUE_CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
enumvalue_customname: _descriptor.FieldDescriptor
GOPROTO_GETTERS_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_getters_all: _descriptor.FieldDescriptor
GOPROTO_ENUM_PREFIX_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_enum_prefix_all: _descriptor.FieldDescriptor
GOPROTO_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_stringer_all: _descriptor.FieldDescriptor
VERBOSE_EQUAL_ALL_FIELD_NUMBER: _ClassVar[int]
verbose_equal_all: _descriptor.FieldDescriptor
FACE_ALL_FIELD_NUMBER: _ClassVar[int]
face_all: _descriptor.FieldDescriptor
GOSTRING_ALL_FIELD_NUMBER: _ClassVar[int]
gostring_all: _descriptor.FieldDescriptor
POPULATE_ALL_FIELD_NUMBER: _ClassVar[int]
populate_all: _descriptor.FieldDescriptor
STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
stringer_all: _descriptor.FieldDescriptor
ONLYONE_ALL_FIELD_NUMBER: _ClassVar[int]
onlyone_all: _descriptor.FieldDescriptor
EQUAL_ALL_FIELD_NUMBER: _ClassVar[int]
equal_all: _descriptor.FieldDescriptor
DESCRIPTION_ALL_FIELD_NUMBER: _ClassVar[int]
description_all: _descriptor.FieldDescriptor
TESTGEN_ALL_FIELD_NUMBER: _ClassVar[int]
testgen_all: _descriptor.FieldDescriptor
BENCHGEN_ALL_FIELD_NUMBER: _ClassVar[int]
benchgen_all: _descriptor.FieldDescriptor
MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
marshaler_all: _descriptor.FieldDescriptor
UNMARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
unmarshaler_all: _descriptor.FieldDescriptor
STABLE_MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
stable_marshaler_all: _descriptor.FieldDescriptor
SIZER_ALL_FIELD_NUMBER: _ClassVar[int]
sizer_all: _descriptor.FieldDescriptor
GOPROTO_ENUM_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_enum_stringer_all: _descriptor.FieldDescriptor
ENUM_STRINGER_ALL_FIELD_NUMBER: _ClassVar[int]
enum_stringer_all: _descriptor.FieldDescriptor
UNSAFE_MARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
unsafe_marshaler_all: _descriptor.FieldDescriptor
UNSAFE_UNMARSHALER_ALL_FIELD_NUMBER: _ClassVar[int]
unsafe_unmarshaler_all: _descriptor.FieldDescriptor
GOPROTO_EXTENSIONS_MAP_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_extensions_map_all: _descriptor.FieldDescriptor
GOPROTO_UNRECOGNIZED_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_unrecognized_all: _descriptor.FieldDescriptor
GOGOPROTO_IMPORT_FIELD_NUMBER: _ClassVar[int]
gogoproto_import: _descriptor.FieldDescriptor
PROTOSIZER_ALL_FIELD_NUMBER: _ClassVar[int]
protosizer_all: _descriptor.FieldDescriptor
COMPARE_ALL_FIELD_NUMBER: _ClassVar[int]
compare_all: _descriptor.FieldDescriptor
TYPEDECL_ALL_FIELD_NUMBER: _ClassVar[int]
typedecl_all: _descriptor.FieldDescriptor
ENUMDECL_ALL_FIELD_NUMBER: _ClassVar[int]
enumdecl_all: _descriptor.FieldDescriptor
GOPROTO_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
goproto_registration: _descriptor.FieldDescriptor
MESSAGENAME_ALL_FIELD_NUMBER: _ClassVar[int]
messagename_all: _descriptor.FieldDescriptor
GOPROTO_SIZECACHE_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_sizecache_all: _descriptor.FieldDescriptor
GOPROTO_UNKEYED_ALL_FIELD_NUMBER: _ClassVar[int]
goproto_unkeyed_all: _descriptor.FieldDescriptor
GOPROTO_GETTERS_FIELD_NUMBER: _ClassVar[int]
goproto_getters: _descriptor.FieldDescriptor
GOPROTO_STRINGER_FIELD_NUMBER: _ClassVar[int]
goproto_stringer: _descriptor.FieldDescriptor
VERBOSE_EQUAL_FIELD_NUMBER: _ClassVar[int]
verbose_equal: _descriptor.FieldDescriptor
FACE_FIELD_NUMBER: _ClassVar[int]
face: _descriptor.FieldDescriptor
GOSTRING_FIELD_NUMBER: _ClassVar[int]
gostring: _descriptor.FieldDescriptor
POPULATE_FIELD_NUMBER: _ClassVar[int]
populate: _descriptor.FieldDescriptor
STRINGER_FIELD_NUMBER: _ClassVar[int]
stringer: _descriptor.FieldDescriptor
ONLYONE_FIELD_NUMBER: _ClassVar[int]
onlyone: _descriptor.FieldDescriptor
EQUAL_FIELD_NUMBER: _ClassVar[int]
equal: _descriptor.FieldDescriptor
DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
description: _descriptor.FieldDescriptor
TESTGEN_FIELD_NUMBER: _ClassVar[int]
testgen: _descriptor.FieldDescriptor
BENCHGEN_FIELD_NUMBER: _ClassVar[int]
benchgen: _descriptor.FieldDescriptor
MARSHALER_FIELD_NUMBER: _ClassVar[int]
marshaler: _descriptor.FieldDescriptor
UNMARSHALER_FIELD_NUMBER: _ClassVar[int]
unmarshaler: _descriptor.FieldDescriptor
STABLE_MARSHALER_FIELD_NUMBER: _ClassVar[int]
stable_marshaler: _descriptor.FieldDescriptor
SIZER_FIELD_NUMBER: _ClassVar[int]
sizer: _descriptor.FieldDescriptor
UNSAFE_MARSHALER_FIELD_NUMBER: _ClassVar[int]
unsafe_marshaler: _descriptor.FieldDescriptor
UNSAFE_UNMARSHALER_FIELD_NUMBER: _ClassVar[int]
unsafe_unmarshaler: _descriptor.FieldDescriptor
GOPROTO_EXTENSIONS_MAP_FIELD_NUMBER: _ClassVar[int]
goproto_extensions_map: _descriptor.FieldDescriptor
GOPROTO_UNRECOGNIZED_FIELD_NUMBER: _ClassVar[int]
goproto_unrecognized: _descriptor.FieldDescriptor
PROTOSIZER_FIELD_NUMBER: _ClassVar[int]
protosizer: _descriptor.FieldDescriptor
COMPARE_FIELD_NUMBER: _ClassVar[int]
compare: _descriptor.FieldDescriptor
TYPEDECL_FIELD_NUMBER: _ClassVar[int]
typedecl: _descriptor.FieldDescriptor
MESSAGENAME_FIELD_NUMBER: _ClassVar[int]
messagename: _descriptor.FieldDescriptor
GOPROTO_SIZECACHE_FIELD_NUMBER: _ClassVar[int]
goproto_sizecache: _descriptor.FieldDescriptor
GOPROTO_UNKEYED_FIELD_NUMBER: _ClassVar[int]
goproto_unkeyed: _descriptor.FieldDescriptor
NULLABLE_FIELD_NUMBER: _ClassVar[int]
nullable: _descriptor.FieldDescriptor
EMBED_FIELD_NUMBER: _ClassVar[int]
embed: _descriptor.FieldDescriptor
CUSTOMTYPE_FIELD_NUMBER: _ClassVar[int]
customtype: _descriptor.FieldDescriptor
CUSTOMNAME_FIELD_NUMBER: _ClassVar[int]
customname: _descriptor.FieldDescriptor
JSONTAG_FIELD_NUMBER: _ClassVar[int]
jsontag: _descriptor.FieldDescriptor
MORETAGS_FIELD_NUMBER: _ClassVar[int]
moretags: _descriptor.FieldDescriptor
CASTTYPE_FIELD_NUMBER: _ClassVar[int]
casttype: _descriptor.FieldDescriptor
CASTKEY_FIELD_NUMBER: _ClassVar[int]
castkey: _descriptor.FieldDescriptor
CASTVALUE_FIELD_NUMBER: _ClassVar[int]
castvalue: _descriptor.FieldDescriptor
STDTIME_FIELD_NUMBER: _ClassVar[int]
stdtime: _descriptor.FieldDescriptor
STDDURATION_FIELD_NUMBER: _ClassVar[int]
stdduration: _descriptor.FieldDescriptor
WKTPOINTER_FIELD_NUMBER: _ClassVar[int]
wktpointer: _descriptor.FieldDescriptor
CASTREPEATED_FIELD_NUMBER: _ClassVar[int]
castrepeated: _descriptor.FieldDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/auth/v1beta1/auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/auth/v1beta1/auth.proto\x12\x13\x63osmos.auth.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xf7\x01\n\x0b\x42\x61seAccount\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12N\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\'\xea\xde\x1f\x14public_key,omitempty\xa2\xe7\xb0*\npublic_key\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x03 \x01(\x04\x12\x10\n\x08sequence\x18\x04 \x01(\x04:C\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1c\x63osmos.auth.v1beta1.AccountI\x8a\xe7\xb0*\x16\x63osmos-sdk/BaseAccount\"\xcc\x01\n\rModuleAccount\x12<\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x04\xd0\xde\x1f\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t:Z\x88\xa0\x1f\x00\xca\xb4-\"cosmos.auth.v1beta1.ModuleAccountI\x8a\xe7\xb0*\x18\x63osmos-sdk/ModuleAccount\x92\xe7\xb0*\x0emodule_account\"h\n\x10ModuleCredential\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65rivation_keys\x18\x02 \x03(\x0c:&\x8a\xe7\xb0*!cosmos-sdk/GroupAccountCredential\"\xf7\x01\n\x06Params\x12\x1b\n\x13max_memo_characters\x18\x01 \x01(\x04\x12\x14\n\x0ctx_sig_limit\x18\x02 \x01(\x04\x12\x1d\n\x15tx_size_cost_per_byte\x18\x03 \x01(\x04\x12\x39\n\x17sig_verify_cost_ed25519\x18\x04 \x01(\x04\x42\x18\xe2\xde\x1f\x14SigVerifyCostED25519\x12=\n\x19sig_verify_cost_secp256k1\x18\x05 \x01(\x04\x42\x1a\xe2\xde\x1f\x16SigVerifyCostSecp256k1:!\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x18\x63osmos-sdk/x/auth/ParamsB+Z)github.com/cosmos/cosmos-sdk/x/auth/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/auth/types'
  _globals['_BASEACCOUNT'].fields_by_name['address']._loaded_options = None
  _globals['_BASEACCOUNT'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_BASEACCOUNT'].fields_by_name['pub_key']._loaded_options = None
  _globals['_BASEACCOUNT'].fields_by_name['pub_key']._serialized_options = b'\352\336\037\024public_key,omitempty\242\347\260*\npublic_key'
  _globals['_BASEACCOUNT']._loaded_options = None
  _globals['_BASEACCOUNT']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\034cosmos.auth.v1beta1.AccountI\212\347\260*\026cosmos-sdk/BaseAccount'
  _globals['_MODULEACCOUNT'].fields_by_name['base_account']._loaded_options = None
  _globals['_MODULEACCOUNT'].fields_by_name['base_account']._serialized_options = b'\320\336\037\001'
  _globals['_MODULEACCOUNT']._loaded_options = None
  _globals['_MODULEACCOUNT']._serialized_options = b'\210\240\037\000\312\264-\"cosmos.auth.v1beta1.ModuleAccountI\212\347\260*\030cosmos-sdk/ModuleAccount\222\347\260*\016module_account'
  _globals['_MODULECREDENTIAL']._loaded_options = None
  _globals['_MODULECREDENTIAL']._serialized_options = b'\212\347\260*!cosmos-sdk/GroupAccountCredential'
  _globals['_PARAMS'].fields_by_name['sig_verify_cost_ed25519']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['sig_verify_cost_ed25519']._serialized_options = b'\342\336\037\024SigVerifyCostED25519'
  _globals['_PARAMS'].fields_by_name['sig_verify_cost_secp256k1']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['sig_verify_cost_secp256k1']._serialized_options = b'\342\336\037\026SigVerifyCostSecp256k1'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\030cosmos-sdk/x/auth/Params'
  _globals['_BASEACCOUNT']._serialized_start=151
  _globals['_BASEACCOUNT']._serialized_end=398
  _globals['_MODULEACCOUNT']._serialized_start=401
  _globals['_MODULEACCOUNT']._serialized_end=605
  _globals['_MODULECREDENTIAL']._serialized_start=607
  _globals['_MODULECREDENTIAL']._serialized_end=711
  _globals['_PARAMS']._serialized_start=714
  _globals['_PARAMS']._serialized_end=961
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/auth/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/auth/v1beta1/query.proto\x12\x13\x63osmos.auth.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1b\x63osmos/query/v1/query.proto\"R\n\x14QueryAccountsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9e\x01\n\x15QueryAccountsResponse\x12H\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB \xca\xb4-\x1c\x63osmos.auth.v1beta1.AccountI\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"J\n\x13QueryAccountRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"_\n\x14QueryAccountResponse\x12G\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB \xca\xb4-\x1c\x63osmos.auth.v1beta1.AccountI\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.auth.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"\x1c\n\x1aQueryModuleAccountsRequest\"m\n\x1bQueryModuleAccountsResponse\x12N\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB&\xca\xb4-\"cosmos.auth.v1beta1.ModuleAccountI\"/\n\x1fQueryModuleAccountByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"q\n QueryModuleAccountByNameResponse\x12M\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB&\xca\xb4-\"cosmos.auth.v1beta1.ModuleAccountI\"\x15\n\x13\x42\x65\x63h32PrefixRequest\"-\n\x14\x42\x65\x63h32PrefixResponse\x12\x15\n\rbech32_prefix\x18\x01 \x01(\t\"4\n\x1b\x41\x64\x64ressBytesToStringRequest\x12\x15\n\raddress_bytes\x18\x01 \x01(\x0c\"6\n\x1c\x41\x64\x64ressBytesToStringResponse\x12\x16\n\x0e\x61\x64\x64ress_string\x18\x01 \x01(\t\"5\n\x1b\x41\x64\x64ressStringToBytesRequest\x12\x16\n\x0e\x61\x64\x64ress_string\x18\x01 \x01(\t\"5\n\x1c\x41\x64\x64ressStringToBytesResponse\x12\x15\n\raddress_bytes\x18\x01 \x01(\x0c\"D\n\x1eQueryAccountAddressByIDRequest\x12\x0e\n\x02id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x12\n\naccount_id\x18\x02 \x01(\x04\"T\n\x1fQueryAccountAddressByIDResponse\x12\x31\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"D\n\x17QueryAccountInfoRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"J\n\x18QueryAccountInfoResponse\x12.\n\x04info\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccount2\xef\x0c\n\x05Query\x12\x8d\x01\n\x08\x41\x63\x63ounts\x12).cosmos.auth.v1beta1.QueryAccountsRequest\x1a*.cosmos.auth.v1beta1.QueryAccountsResponse\"*\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/auth/v1beta1/accounts\x12\x94\x01\n\x07\x41\x63\x63ount\x12(.cosmos.auth.v1beta1.QueryAccountRequest\x1a).cosmos.auth.v1beta1.QueryAccountResponse\"4\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02)\x12\'/cosmos/auth/v1beta1/accounts/{address}\x12\xb5\x01\n\x12\x41\x63\x63ountAddressByID\x12\x33.cosmos.auth.v1beta1.QueryAccountAddressByIDRequest\x1a\x34.cosmos.auth.v1beta1.QueryAccountAddressByIDResponse\"4\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02)\x12\'/cosmos/auth/v1beta1/address_by_id/{id}\x12\x85\x01\n\x06Params\x12\'.cosmos.auth.v1beta1.QueryParamsRequest\x1a(.cosmos.auth.v1beta1.QueryParamsResponse\"(\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/auth/v1beta1/params\x12\xa6\x01\n\x0eModuleAccounts\x12/.cosmos.auth.v1beta1.QueryModuleAccountsRequest\x1a\x30.cosmos.auth.v1beta1.QueryModuleAccountsResponse\"1\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02&\x12$/cosmos/auth/v1beta1/module_accounts\x12\xbc\x01\n\x13ModuleAccountByName\x12\x34.cosmos.auth.v1beta1.QueryModuleAccountByNameRequest\x1a\x35.cosmos.auth.v1beta1.QueryModuleAccountByNameResponse\"8\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02-\x12+/cosmos/auth/v1beta1/module_accounts/{name}\x12\x88\x01\n\x0c\x42\x65\x63h32Prefix\x12(.cosmos.auth.v1beta1.Bech32PrefixRequest\x1a).cosmos.auth.v1beta1.Bech32PrefixResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/auth/v1beta1/bech32\x12\xb0\x01\n\x14\x41\x64\x64ressBytesToString\x12\x30.cosmos.auth.v1beta1.AddressBytesToStringRequest\x1a\x31.cosmos.auth.v1beta1.AddressBytesToStringResponse\"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/auth/v1beta1/bech32/{address_bytes}\x12\xb1\x01\n\x14\x41\x64\x64ressStringToBytes\x12\x30.cosmos.auth.v1beta1.AddressStringToBytesRequest\x1a\x31.cosmos.auth.v1beta1.AddressStringToBytesResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/auth/v1beta1/bech32/{address_string}\x12\xa4\x01\n\x0b\x41\x63\x63ountInfo\x12,.cosmos.auth.v1beta1.QueryAccountInfoRequest\x1a-.cosmos.auth.v1beta1.QueryAccountInfoResponse\"8\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02-\x12+/cosmos/auth/v1beta1/account_info/{address}B+Z)github.com/cosmos/cosmos-sdk/x/auth/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.auth.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/auth/types'
  _globals['_QUERYACCOUNTSRESPONSE'].fields_by_name['accounts']._loaded_options = None
  _globals['_QUERYACCOUNTSRESPONSE'].fields_by_name['accounts']._serialized_options = b'\312\264-\034cosmos.auth.v1beta1.AccountI'
  _globals['_QUERYACCOUNTREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYACCOUNTREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYACCOUNTREQUEST']._loaded_options = None
  _globals['_QUERYACCOUNTREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYACCOUNTRESPONSE'].fields_by_name['account']._loaded_options = None
  _globals['_QUERYACCOUNTRESPONSE'].fields_by_name['account']._serialized_options = b'\312\264-\034cosmos.auth.v1beta1.AccountI'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMODULEACCOUNTSRESPONSE'].fields_by_name['accounts']._loaded_options = None
  _globals['_QUERYMODULEACCOUNTSRESPONSE'].fields_by_name['accounts']._serialized_options = b'\312\264-\"cosmos.auth.v1beta1.ModuleAccountI'
  _globals['_QUERYMODULEACCOUNTBYNAMERESPONSE'].fields_by_name['account']._loaded_options = None
  _globals['_QUERYMODULEACCOUNTBYNAMERESPONSE'].fields_by_name['account']._serialized_options = b'\312\264-\"cosmos.auth.v1beta1.ModuleAccountI'
  _globals['_QUERYACCOUNTADDRESSBYIDREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_QUERYACCOUNTADDRESSBYIDREQUEST'].fields_by_name['id']._serialized_options = b'\030\001'
  _globals['_QUERYACCOUNTADDRESSBYIDRESPONSE'].fields_by_name['account_address']._loaded_options = None
  _globals['_QUERYACCOUNTADDRESSBYIDRESPONSE'].fields_by_name['account_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYACCOUNTINFOREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYACCOUNTINFOREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['Accounts']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Accounts']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\037\022\035/cosmos/auth/v1beta1/accounts'
  _globals['_QUERY'].methods_by_name['Account']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Account']._serialized_options = b'\210\347\260*\001\202\323\344\223\002)\022\'/cosmos/auth/v1beta1/accounts/{address}'
  _globals['_QUERY'].methods_by_name['AccountAddressByID']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AccountAddressByID']._serialized_options = b'\210\347\260*\001\202\323\344\223\002)\022\'/cosmos/auth/v1beta1/address_by_id/{id}'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\035\022\033/cosmos/auth/v1beta1/params'
  _globals['_QUERY'].methods_by_name['ModuleAccounts']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ModuleAccounts']._serialized_options = b'\210\347\260*\001\202\323\344\223\002&\022$/cosmos/auth/v1beta1/module_accounts'
  _globals['_QUERY'].methods_by_name['ModuleAccountByName']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ModuleAccountByName']._serialized_options = b'\210\347\260*\001\202\323\344\223\002-\022+/cosmos/auth/v1beta1/module_accounts/{name}'
  _globals['_QUERY'].methods_by_name['Bech32Prefix']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Bech32Prefix']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/auth/v1beta1/bech32'
  _globals['_QUERY'].methods_by_name['AddressBytesToString']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AddressBytesToString']._serialized_options = b'\202\323\344\223\002-\022+/cosmos/auth/v1beta1/bech32/{address_bytes}'
  _globals['_QUERY'].methods_by_name['AddressStringToBytes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AddressStringToBytes']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/auth/v1beta1/bech32/{address_string}'
  _globals['_QUERY'].methods_by_name['AccountInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AccountInfo']._serialized_options = b'\210\347\260*\001\202\323\344\223\002-\022+/cosmos/auth/v1beta1/account_info/{address}'
  _globals['_QUERYACCOUNTSREQUEST']._serialized_start=267
  _globals['_QUERYACCOUNTSREQUEST']._serialized_end=349
  _globals['_QUERYACCOUNTSRESPONSE']._serialized_start=352
  _globals['_QUERYACCOUNTSRESPONSE']._serialized_end=510
  _globals['_QUERYACCOUNTREQUEST']._serialized_start=512
  _globals['_QUERYACCOUNTREQUEST']._serialized_end=586
  _globals['_QUERYACCOUNTRESPONSE']._serialized_start=588
  _globals['_QUERYACCOUNTRESPONSE']._serialized_end=683
  _globals['_QUERYPARAMSREQUEST']._serialized_start=685
  _globals['_QUERYPARAMSREQUEST']._serialized_end=705
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=707
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=779
  _globals['_QUERYMODULEACCOUNTSREQUEST']._serialized_start=781
  _globals['_QUERYMODULEACCOUNTSREQUEST']._serialized_end=809
  _globals['_QUERYMODULEACCOUNTSRESPONSE']._serialized_start=811
  _globals['_QUERYMODULEACCOUNTSRESPONSE']._serialized_end=920
  _globals['_QUERYMODULEACCOUNTBYNAMEREQUEST']._serialized_start=922
  _globals['_QUERYMODULEACCOUNTBYNAMEREQUEST']._serialized_end=969
  _globals['_QUERYMODULEACCOUNTBYNAMERESPONSE']._serialized_start=971
  _globals['_QUERYMODULEACCOUNTBYNAMERESPONSE']._serialized_end=1084
  _globals['_BECH32PREFIXREQUEST']._serialized_start=1086
  _globals['_BECH32PREFIXREQUEST']._serialized_end=1107
  _globals['_BECH32PREFIXRESPONSE']._serialized_start=1109
  _globals['_BECH32PREFIXRESPONSE']._serialized_end=1154
  _globals['_ADDRESSBYTESTOSTRINGREQUEST']._serialized_start=1156
  _globals['_ADDRESSBYTESTOSTRINGREQUEST']._serialized_end=1208
  _globals['_ADDRESSBYTESTOSTRINGRESPONSE']._serialized_start=1210
  _globals['_ADDRESSBYTESTOSTRINGRESPONSE']._serialized_end=1264
  _globals['_ADDRESSSTRINGTOBYTESREQUEST']._serialized_start=1266
  _globals['_ADDRESSSTRINGTOBYTESREQUEST']._serialized_end=1319
  _globals['_ADDRESSSTRINGTOBYTESRESPONSE']._serialized_start=1321
  _globals['_ADDRESSSTRINGTOBYTESRESPONSE']._serialized_end=1374
  _globals['_QUERYACCOUNTADDRESSBYIDREQUEST']._serialized_start=1376
  _globals['_QUERYACCOUNTADDRESSBYIDREQUEST']._serialized_end=1444
  _globals['_QUERYACCOUNTADDRESSBYIDRESPONSE']._serialized_start=1446
  _globals['_QUERYACCOUNTADDRESSBYIDRESPONSE']._serialized_end=1530
  _globals['_QUERYACCOUNTINFOREQUEST']._serialized_start=1532
  _globals['_QUERYACCOUNTINFOREQUEST']._serialized_end=1600
  _globals['_QUERYACCOUNTINFORESPONSE']._serialized_start=1602
  _globals['_QUERYACCOUNTINFORESPONSE']._serialized_end=1676
  _globals['_QUERY']._serialized_start=1679
  _globals['_QUERY']._serialized_end=3326
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.dydxprotocol.bridge import bridge_event_pb2 as _bridge_event_pb2
from v4_proto.dydxprotocol.bridge import params_pb2 as _params_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgAcknowledgeBridges(_message.Message):
    __slots__ = ("events",)
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[_bridge_event_pb2.BridgeEvent]
    def __init__(self, events: _Optional[_Iterable[_Union[_bridge_event_pb2.BridgeEvent, _Mapping]]] = ...) -> None: ...

class MsgAcknowledgeBridgesResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgCompleteBridge(_message.Message):
    __slots__ = ("authority", "event")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    authority: str
    event: _bridge_event_pb2.BridgeEvent
    def __init__(self, authority: _Optional[str] = ..., event: _Optional[_Union[_bridge_event_pb2.BridgeEvent, _Mapping]] = ...) -> None: ...

class MsgCompleteBridgeResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateEventParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.EventParams
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.EventParams, _Mapping]] = ...) -> None: ...

class MsgUpdateEventParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateProposeParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.ProposeParams
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.ProposeParams, _Mapping]] = ...) -> None: ...

class MsgUpdateProposeParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateSafetyParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.SafetyParams
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.SafetyParams, _Mapping]] = ...) -> None: ...

class MsgUpdateSafetyParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("funding_rate_clamp_factor_ppm", "premium_vote_clamp_factor_ppm", "min_num_votes_per_sample")
    FUNDING_RATE_CLAMP_FACTOR_PPM_FIELD_NUMBER: _ClassVar[int]
    PREMIUM_VOTE_CLAMP_FACTOR_PPM_FIELD_NUMBER: _ClassVar[int]
    MIN_NUM_VOTES_PER_SAMPLE_FIELD_NUMBER: _ClassVar[int]
    funding_rate_clamp_factor_ppm: int
    premium_vote_clamp_factor_ppm: int
    min_num_votes_per_sample: int
    def __init__(self, funding_rate_clamp_factor_ppm: _Optional[int] = ..., premium_vote_clamp_factor_ppm: _Optional[int] = ..., min_num_votes_per_sample: _Optional[int] = ...) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryGetSubaccountRequest(_message.Message):
    __slots__ = ("owner", "number")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    owner: str
    number: int
    def __init__(self, owner: _Optional[str] = ..., number: _Optional[int] = ...) -> None: ...

class QuerySubaccountResponse(_message.Message):
    __slots__ = ("subaccount",)
    SUBACCOUNT_FIELD_NUMBER: _ClassVar[int]
    subaccount: _subaccount_pb2.Subaccount
    def __init__(self, subaccount: _Optional[_Union[_subaccount_pb2.Subaccount, _Mapping]] = ...) -> None: ...

class QueryAllSubaccountRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySubaccountAllResponse(_message.Message):
    __slots__ = ("subaccount", "pagination")
    SUBACCOUNT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    subaccount: _containers.RepeatedCompositeFieldContainer[_subaccount_pb2.Subaccount]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, subaccount: _Optional[_Iterable[_Union[_subaccount_pb2.Subaccount, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGetWithdrawalAndTransfersBlockedInfoRequest(_message.Message):
    __slots__ = ("perpetual_id",)
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    def __init__(self, perpetual_id: _Optional[int] = ...) -> None: ...

class QueryGetWithdrawalAndTransfersBlockedInfoResponse(_message.Message):
    __slots__ = ("negative_tnc_subaccount_seen_at_block", "chain_outage_seen_at_block", "withdrawals_and_transfers_unblocked_at_block")
    NEGATIVE_TNC_SUBACCOUNT_SEEN_AT_BLOCK_FIELD_NUMBER: _ClassVar[int]
    CHAIN_OUTAGE_SEEN_AT_BLOCK_FIELD_NUMBER: _ClassVar[int]
    WITHDRAWALS_AND_TRANSFERS_UNBLOCKED_AT_BLOCK_FIELD_NUMBER: _ClassVar[int]
    negative_tnc_subaccount_seen_at_block: int
    chain_outage_seen_at_block: int
    withdrawals_and_transfers_unblocked_at_block: int
    def __init__(self, negative_tnc_subaccount_seen_at_block: _Optional[int] = ..., chain_outage_seen_at_block: _Optional[int] = ..., withdrawals_and_transfers_unblocked_at_block: _Optional[int] = ...) -> None: ...

class QueryCollateralPoolAddressRequest(_message.Message):
    __slots__ = ("perpetual_id",)
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    def __init__(self, perpetual_id: _Optional[int] = ...) -> None: ...

class QueryCollateralPoolAddressResponse(_message.Message):
    __slots__ = ("collateral_pool_address",)
    COLLATERAL_POOL_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    collateral_pool_address: str
    def __init__(self, collateral_pool_address: _Optional[str] = ...) -> None: ...



from v4_proto.dydxprotocol.sending import transfer_pb2 as _transfer_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateTransfer(_message.Message):
    __slots__ = ("transfer",)
    TRANSFER_FIELD_NUMBER: _ClassVar[int]
    transfer: _transfer_pb2.Transfer
    def __init__(self, transfer: _Optional[_Union[_transfer_pb2.Transfer, _Mapping]] = ...) -> None: ...

class MsgCreateTransferResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgDepositToSubaccountResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgWithdrawFromSubaccountResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSendFromModuleToAccountResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/equity_tier_limit_config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0dydxprotocol/clob/equity_tier_limit_config.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\"\xbe\x01\n\x1c\x45quityTierLimitConfiguration\x12O\n\x1dshort_term_order_equity_tiers\x18\x01 \x03(\x0b\x32\".dydxprotocol.clob.EquityTierLimitB\x04\xc8\xde\x1f\x00\x12M\n\x1bstateful_order_equity_tiers\x18\x02 \x03(\x0b\x32\".dydxprotocol.clob.EquityTierLimitB\x04\xc8\xde\x1f\x00\"\x84\x01\n\x0f\x45quityTierLimit\x12\x62\n\x10usd_tnc_required\x18\x01 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\r\n\x05limit\x18\x02 \x01(\rB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.equity_tier_limit_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_EQUITYTIERLIMITCONFIGURATION'].fields_by_name['short_term_order_equity_tiers']._loaded_options = None
  _globals['_EQUITYTIERLIMITCONFIGURATION'].fields_by_name['short_term_order_equity_tiers']._serialized_options = b'\310\336\037\000'
  _globals['_EQUITYTIERLIMITCONFIGURATION'].fields_by_name['stateful_order_equity_tiers']._loaded_options = None
  _globals['_EQUITYTIERLIMITCONFIGURATION'].fields_by_name['stateful_order_equity_tiers']._serialized_options = b'\310\336\037\000'
  _globals['_EQUITYTIERLIMIT'].fields_by_name['usd_tnc_required']._loaded_options = None
  _globals['_EQUITYTIERLIMIT'].fields_by_name['usd_tnc_required']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_EQUITYTIERLIMITCONFIGURATION']._serialized_start=94
  _globals['_EQUITYTIERLIMITCONFIGURATION']._serialized_end=284
  _globals['_EQUITYTIERLIMIT']._serialized_start=287
  _globals['_EQUITYTIERLIMIT']._serialized_end=419
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("window_duration",)
    WINDOW_DURATION_FIELD_NUMBER: _ClassVar[int]
    window_duration: _duration_pb2.Duration
    def __init__(self, window_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/authz.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/bank/v1beta1/authz.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x82\x02\n\x11SendAuthorization\x12v\n\x0bspend_limit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12,\n\nallow_list\x18\x02 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:G\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*\x1c\x63osmos-sdk/SendAuthorizationB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _globals['_SENDAUTHORIZATION'].fields_by_name['spend_limit']._loaded_options = None
  _globals['_SENDAUTHORIZATION'].fields_by_name['spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_SENDAUTHORIZATION'].fields_by_name['allow_list']._loaded_options = None
  _globals['_SENDAUTHORIZATION'].fields_by_name['allow_list']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_SENDAUTHORIZATION']._loaded_options = None
  _globals['_SENDAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*\034cosmos-sdk/SendAuthorization'
  _globals['_SENDAUTHORIZATION']._serialized_start=157
  _globals['_SENDAUTHORIZATION']._serialized_end=415
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/vault/genesis.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\"k\n\x0cGenesisState\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.vault.ParamsB\x04\xc8\xde\x1f\x00\x12)\n\x06vaults\x18\x02 \x03(\x0b\x32\x19.dydxprotocol.vault.Vault\"\xf8\x01\n\x05Vault\x12-\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultId\x12\x33\n\x0ctotal_shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumShares\x12\x34\n\x0cowner_shares\x18\x03 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShare\x12\x35\n\x0cvault_params\x18\x04 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParams\x12\x1e\n\x16most_recent_client_ids\x18\x05 \x03(\rB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=143
  _globals['_GENESISSTATE']._serialized_end=250
  _globals['_VAULT']._serialized_start=253
  _globals['_VAULT']._serialized_end=501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/multisig/keys.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/crypto/multisig/keys.proto\x12\x16\x63osmos.crypto.multisig\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x11\x61mino/amino.proto\"\xac\x01\n\x11LegacyAminoPubKey\x12\x11\n\tthreshold\x18\x01 \x01(\r\x12\x42\n\x0bpublic_keys\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB\x17\xe2\xde\x1f\x07PubKeys\xa2\xe7\xb0*\x07pubkeys:@\x88\xa0\x1f\x00\x8a\xe7\xb0*\"tendermint/PubKeyMultisigThreshold\x92\xe7\xb0*\x10threshold_stringB3Z1github.com/cosmos/cosmos-sdk/crypto/keys/multisigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.multisig.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/crypto/keys/multisig'
  _globals['_LEGACYAMINOPUBKEY'].fields_by_name['public_keys']._loaded_options = None
  _globals['_LEGACYAMINOPUBKEY'].fields_by_name['public_keys']._serialized_options = b'\342\336\037\007PubKeys\242\347\260*\007pubkeys'
  _globals['_LEGACYAMINOPUBKEY']._loaded_options = None
  _globals['_LEGACYAMINOPUBKEY']._serialized_options = b'\210\240\037\000\212\347\260*\"tendermint/PubKeyMultisigThreshold\222\347\260*\020threshold_string'
  _globals['_LEGACYAMINOPUBKEY']._serialized_start=130
  _globals['_LEGACYAMINOPUBKEY']._serialized_end=302
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class OrderRemovalReason(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ORDER_REMOVAL_REASON_UNSPECIFIED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_EXPIRED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_USER_CANCELED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_UNDERCOLLATERALIZED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_INTERNAL_ERROR: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_SELF_TRADE_ERROR: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_POST_ONLY_WOULD_CROSS_MAKER_ORDER: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_IMMEDIATE_OR_CANCEL_WOULD_REST_ON_BOOK: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_FOK_ORDER_COULD_NOT_BE_FULLY_FULLED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_REDUCE_ONLY_RESIZE: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_INDEXER_EXPIRED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_REPLACED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_FULLY_FILLED: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_EQUITY_TIER: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_FINAL_SETTLEMENT: _ClassVar[OrderRemovalReason]
    ORDER_REMOVAL_REASON_VIOLATES_ISOLATED_SUBACCOUNT_CONSTRAINTS: _ClassVar[OrderRemovalReason]
ORDER_REMOVAL_REASON_UNSPECIFIED: OrderRemovalReason
ORDER_REMOVAL_REASON_EXPIRED: OrderRemovalReason
ORDER_REMOVAL_REASON_USER_CANCELED: OrderRemovalReason
ORDER_REMOVAL_REASON_UNDERCOLLATERALIZED: OrderRemovalReason
ORDER_REMOVAL_REASON_INTERNAL_ERROR: OrderRemovalReason
ORDER_REMOVAL_REASON_SELF_TRADE_ERROR: OrderRemovalReason
ORDER_REMOVAL_REASON_POST_ONLY_WOULD_CROSS_MAKER_ORDER: OrderRemovalReason
ORDER_REMOVAL_REASON_IMMEDIATE_OR_CANCEL_WOULD_REST_ON_BOOK: OrderRemovalReason
ORDER_REMOVAL_REASON_FOK_ORDER_COULD_NOT_BE_FULLY_FULLED: OrderRemovalReason
ORDER_REMOVAL_REASON_REDUCE_ONLY_RESIZE: OrderRemovalReason
ORDER_REMOVAL_REASON_INDEXER_EXPIRED: OrderRemovalReason
ORDER_REMOVAL_REASON_REPLACED: OrderRemovalReason
ORDER_REMOVAL_REASON_FULLY_FILLED: OrderRemovalReason
ORDER_REMOVAL_REASON_EQUITY_TIER: OrderRemovalReason
ORDER_REMOVAL_REASON_FINAL_SETTLEMENT: OrderRemovalReason
ORDER_REMOVAL_REASON_VIOLATES_ISOLATED_SUBACCOUNT_CONSTRAINTS: OrderRemovalReason



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrderId(_message.Message):
    __slots__ = ("subaccount_id", "client_id", "order_flags", "clob_pair_id")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_FLAGS_FIELD_NUMBER: _ClassVar[int]
    CLOB_PAIR_ID_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.SubaccountId
    client_id: int
    order_flags: int
    clob_pair_id: int
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., client_id: _Optional[int] = ..., order_flags: _Optional[int] = ..., clob_pair_id: _Optional[int] = ...) -> None: ...

class OrdersFilledDuringLatestBlock(_message.Message):
    __slots__ = ("order_ids",)
    ORDER_IDS_FIELD_NUMBER: _ClassVar[int]
    order_ids: _containers.RepeatedCompositeFieldContainer[OrderId]
    def __init__(self, order_ids: _Optional[_Iterable[_Union[OrderId, _Mapping]]] = ...) -> None: ...

class PotentiallyPrunableOrders(_message.Message):
    __slots__ = ("order_ids",)
    ORDER_IDS_FIELD_NUMBER: _ClassVar[int]
    order_ids: _containers.RepeatedCompositeFieldContainer[OrderId]
    def __init__(self, order_ids: _Optional[_Iterable[_Union[OrderId, _Mapping]]] = ...) -> None: ...

class OrderFillState(_message.Message):
    __slots__ = ("fill_amount", "prunable_block_height")
    FILL_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    PRUNABLE_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    fill_amount: int
    prunable_block_height: int
    def __init__(self, fill_amount: _Optional[int] = ..., prunable_block_height: _Optional[int] = ...) -> None: ...

class StatefulOrderTimeSliceValue(_message.Message):
    __slots__ = ("order_ids",)
    ORDER_IDS_FIELD_NUMBER: _ClassVar[int]
    order_ids: _containers.RepeatedCompositeFieldContainer[OrderId]
    def __init__(self, order_ids: _Optional[_Iterable[_Union[OrderId, _Mapping]]] = ...) -> None: ...

class LongTermOrderPlacement(_message.Message):
    __slots__ = ("order", "placement_index")
    ORDER_FIELD_NUMBER: _ClassVar[int]
    PLACEMENT_INDEX_FIELD_NUMBER: _ClassVar[int]
    order: Order
    placement_index: TransactionOrdering
    def __init__(self, order: _Optional[_Union[Order, _Mapping]] = ..., placement_index: _Optional[_Union[TransactionOrdering, _Mapping]] = ...) -> None: ...

class ConditionalOrderPlacement(_message.Message):
    __slots__ = ("order", "placement_index", "trigger_index")
    ORDER_FIELD_NUMBER: _ClassVar[int]
    PLACEMENT_INDEX_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_INDEX_FIELD_NUMBER: _ClassVar[int]
    order: Order
    placement_index: TransactionOrdering
    trigger_index: TransactionOrdering
    def __init__(self, order: _Optional[_Union[Order, _Mapping]] = ..., placement_index: _Optional[_Union[TransactionOrdering, _Mapping]] = ..., trigger_index: _Optional[_Union[TransactionOrdering, _Mapping]] = ...) -> None: ...

class Order(_message.Message):
    __slots__ = ("order_id", "side", "quantums", "subticks", "good_til_block", "good_til_block_time", "time_in_force", "reduce_only", "client_metadata", "condition_type", "conditional_order_trigger_subticks")
    class Side(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        SIDE_UNSPECIFIED: _ClassVar[Order.Side]
        SIDE_BUY: _ClassVar[Order.Side]
        SIDE_SELL: _ClassVar[Order.Side]
    SIDE_UNSPECIFIED: Order.Side
    SIDE_BUY: Order.Side
    SIDE_SELL: Order.Side
    class TimeInForce(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TIME_IN_FORCE_UNSPECIFIED: _ClassVar[Order.TimeInForce]
        TIME_IN_FORCE_IOC: _ClassVar[Order.TimeInForce]
        TIME_IN_FORCE_POST_ONLY: _ClassVar[Order.TimeInForce]
        TIME_IN_FORCE_FILL_OR_KILL: _ClassVar[Order.TimeInForce]
    TIME_IN_FORCE_UNSPECIFIED: Order.TimeInForce
    TIME_IN_FORCE_IOC: Order.TimeInForce
    TIME_IN_FORCE_POST_ONLY: Order.TimeInForce
    TIME_IN_FORCE_FILL_OR_KILL: Order.TimeInForce
    class ConditionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        CONDITION_TYPE_UNSPECIFIED: _ClassVar[Order.ConditionType]
        CONDITION_TYPE_STOP_LOSS: _ClassVar[Order.ConditionType]
        CONDITION_TYPE_TAKE_PROFIT: _ClassVar[Order.ConditionType]
    CONDITION_TYPE_UNSPECIFIED: Order.ConditionType
    CONDITION_TYPE_STOP_LOSS: Order.ConditionType
    CONDITION_TYPE_TAKE_PROFIT: Order.ConditionType
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    SIDE_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    SUBTICKS_FIELD_NUMBER: _ClassVar[int]
    GOOD_TIL_BLOCK_FIELD_NUMBER: _ClassVar[int]
    GOOD_TIL_BLOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    TIME_IN_FORCE_FIELD_NUMBER: _ClassVar[int]
    REDUCE_ONLY_FIELD_NUMBER: _ClassVar[int]
    CLIENT_METADATA_FIELD_NUMBER: _ClassVar[int]
    CONDITION_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONDITIONAL_ORDER_TRIGGER_SUBTICKS_FIELD_NUMBER: _ClassVar[int]
    order_id: OrderId
    side: Order.Side
    quantums: int
    subticks: int
    good_til_block: int
    good_til_block_time: int
    time_in_force: Order.TimeInForce
    reduce_only: bool
    client_metadata: int
    condition_type: Order.ConditionType
    conditional_order_trigger_subticks: int
    def __init__(self, order_id: _Optional[_Union[OrderId, _Mapping]] = ..., side: _Optional[_Union[Order.Side, str]] = ..., quantums: _Optional[int] = ..., subticks: _Optional[int] = ..., good_til_block: _Optional[int] = ..., good_til_block_time: _Optional[int] = ..., time_in_force: _Optional[_Union[Order.TimeInForce, str]] = ..., reduce_only: bool = ..., client_metadata: _Optional[int] = ..., condition_type: _Optional[_Union[Order.ConditionType, str]] = ..., conditional_order_trigger_subticks: _Optional[int] = ...) -> None: ...

class TransactionOrdering(_message.Message):
    __slots__ = ("block_height", "transaction_index")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_INDEX_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    transaction_index: int
    def __init__(self, block_height: _Optional[int] = ..., transaction_index: _Optional[int] = ...) -> None: ...
